@@ -1,36 +1,21 @@
 ## ----setup, include = FALSE---------------------------------------------------
-knitr::opts_chunk$set(collapse = TRUE,
-  comment = "#>",
-  message = FALSE,
-  warning = FALSE,
-  eval = nzchar(Sys.getenv("COMPILE_VIG")))
+knitr::opts_chunk$set(warning = FALSE, message = FALSE)
 library(cancensus)
 
-# Adding a check for CensusMapper server status. There are occasional cert and other issues affecting CensusMapper servers, and this causes failure of some automated testing - CRAN in particular. If this check passes, we move on and compile the rest of the vignette. If it fails, we compile without evaluating. 
-check <- tryCatch(get_census(dataset='CA16', regions=list(CMA="59933"),
-           vectors=c("v_CA16_408"),
-           level='CMA', use_cache = FALSE, geo_format = NA), error = function(e) {print("Invalid")})
-
-if(class(check)=="character") {
-  eval = FALSE
-}
-
 ## -----------------------------------------------------------------------------
 list_census_datasets()
 
 ## ----echo=FALSE---------------------------------------------------------------
 library(ggplot2)
 library(dplyr)
-ca16 <- list_census_vectors("CA16")
-ca11 <- list_census_vectors("CA11")
-ca06 <- list_census_vectors("CA06")
-ca01 <- list_census_vectors("CA01")
-ca96 <- list_census_vectors("CA1996")
+datasets <- c("CA1996","CA01","CA06","CA11","CA16","CA21")
 
-tibble(dataset = c("CA16","CA11","CA06","CA01","CA1996"), 
-       vectors = c(length(ca16$vector), length(ca11$vector),
-                   length(ca06$vector), length(ca01$vector),
-                   length(ca96$vector))) %>% 
+datasets %>%
+  lapply(function(ds){
+    dplyr::tibble(dataset=ds, vectors=nrow(list_census_vectors(ds)))
+  }) %>%
+  bind_rows() %>%
+  mutate(dataset=factor(dataset,levels=datasets)) %>%
   ggplot(., aes(x = dataset, y = vectors)) +
   geom_col() +
   theme_minimal() +
@@ -40,7 +25,7 @@ tibble(dataset = c("CA16","CA11","CA06","CA01","CA1996"),
   scale_y_continuous(labels = scales::comma)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-list_census_vectors('CA16')
+list_census_vectors('CA21')
 
 ## ---- warning=TRUE, message=TRUE----------------------------------------------
 find_census_vectors("Oji-cree", dataset = "CA16", type = "total", query_type = "exact")
@@ -69,7 +54,7 @@ list_census_regions('CA16') %>%
   tally()
 
 ## -----------------------------------------------------------------------------
-list_census_regions('CA16')
+list_census_regions('CA21')
 
 ## ----echo=FALSE, paged.print=TRUE---------------------------------------------
 if(Sys.getenv("COMPILE_VIG")=="TRUE") {
@@ -77,5 +62,5 @@ if(Sys.getenv("COMPILE_VIG")=="TRUE") {
 }
 
 ## -----------------------------------------------------------------------------
-search_census_regions("Vancouver","CA16")
+search_census_regions("Vancouver","CA21")
 
